## Background

The genealogies of a population reflect population events of the past.

## Definition of lineal admixture time

We define lineal admixture time per lineage. This measure in time duration depends on two reference time points:

1. a past time horizon when all ancestors are members of separate non-admixed subpopulations, and

2. an observation time, such as the present.

Given a lineage, the lineal admixture time is defined as:

the amount of time since fertilization of the first admixed individual in the lineage.